timeintervaltools.calculate_sustain_centroid_of_intervals
=========================================================

.. autofunction:: abjad.tools.timeintervaltools.calculate_sustain_centroid_of_intervals.calculate_sustain_centroid_of_intervals
